ConstraintSense

Enum ConstraintSense 

pub enum ConstraintSense {
    GreaterEqual,
    LessEqual,
    Equal,
}
Comparison sense for a generic constraint.

Variants



GreaterEqual

The expression must be greater than or equal to the bound (>=).



LessEqual

The expression must be less than or equal to the bound (<=).



Equal

The expression must be exactly equal to the bound (==).