SlackConfig

Struct SlackConfig 

pub struct SlackConfig {
    pub enabled: bool,
    pub penalty: Option<f64>,
}
Slack variable configuration for a generic constraint.

When enabled is true, a slack variable is added to the LP so that the constraint can be violated at a cost. This prevents infeasibility when bounds are tight or conflicting. The penalty cost enters the LP objective function.

penalty must be Some(value) with a positive value when enabled is true, and None when enabled is false.

Fields

enabled: bool

Whether a slack variable is added to allow soft violation of the constraint.

penalty: Option<f64>

Penalty cost per unit of constraint violation. None when enabled is false.